@@ -86,18 +86,18 @@ test_that("find_names finds all valid variable names in a string", {
   expect_equal(find_names(string), c("x", "b.x", "a__3"))
 })
 
-test_that("arma_predictor runs without errors", {
+test_that(".predictor_arma runs without errors", {
   ns <- 20
   nobs <- 30
-  data <- list(
+  sdata <- list(
     Y = rnorm(nobs), 
     J_lag = c(1:3, 3, 3, rep(c(0:3, 3), 4), 0:3, 0)
   )
   ar <- matrix(rnorm(ns * 3), nrow = ns, ncol = 3)
   ma <- matrix(rnorm(ns * 1), nrow = ns, ncol = 1)
   eta <- matrix(rnorm(ns * nobs), nrow = ns, ncol = nobs)
-  expect_equal(arma_predictor(standata = data, eta = eta), eta)
-  expect_silent(arma_predictor(standata = data, eta = eta, ar = ar))
-  expect_silent(arma_predictor(standata = data, eta = eta, ma = ma))
-  expect_silent(arma_predictor(standata = data, eta = eta, ar = ar, ma = ma))
+  expect_equal(.predictor_arma(eta, sdata = sdata), eta)
+  expect_silent(.predictor_arma(eta, sdata = sdata, ar = ar))
+  expect_silent(.predictor_arma(eta, sdata = sdata, ma = ma))
+  expect_silent(.predictor_arma(eta, sdata = sdata, ar = ar, ma = ma))
 })
